@@ -16,16 +16,6 @@
 # You should have received a copy of the GNU General Public License
 # along with scattermore. If not, see <https://www.gnu.org/licenses/>.
 
-# set global variables
 scattermore.globals <- list(
-  dim_RGBWT = 5,
-  dim_RGBA = 4,
-  epsilon = 1e-9,
-  length_xy_lines = 4,
-  R = 1,
-  G = 2,
-  B = 3,
-  W = 4,
-  A = 4,
-  T = 5
+  epsilon = 1e-9
 )
